import type { CreateRunnerOrganisation } from '../models/CreateRunnerOrganisation';
import type { ResponseEmpty } from '../models/ResponseEmpty';
import type { ResponseRunnerOrganisation } from '../models/ResponseRunnerOrganisation';
import type { UpdateRunnerOrganisation } from '../models/UpdateRunnerOrganisation';
export declare class RunnerOrganisationService {
    /**
     * Get all
     * Lists all organisations. <br> This includes their address, contact and teams (if existing/associated).
     * @returns ResponseRunnerOrganisation
     * @throws ApiError
     */
    static runnerOrganisationControllerGetAll(): Promise<Array<ResponseRunnerOrganisation>>;
    /**
     * Post
     * Create a new organsisation.
     * @param requestBody CreateRunnerOrganisation
     * @returns ResponseRunnerOrganisation
     * @throws ApiError
     */
    static runnerOrganisationControllerPost(requestBody?: CreateRunnerOrganisation): Promise<ResponseRunnerOrganisation>;
    /**
     * Get one
     * Lists all information about the organisation whose id got provided.
     * @param id
     * @returns ResponseRunnerOrganisation
     * @throws ApiError
     */
    static runnerOrganisationControllerGetOne(id: number): Promise<ResponseRunnerOrganisation>;
    /**
     * Put
     * Update the organisation whose id you provided. <br> Please remember that ids can't be changed.
     * @param id
     * @param requestBody UpdateRunnerOrganisation
     * @returns ResponseRunnerOrganisation
     * @throws ApiError
     */
    static runnerOrganisationControllerPut(id: number, requestBody?: UpdateRunnerOrganisation): Promise<ResponseRunnerOrganisation>;
    /**
     * Remove
     * Delete the organsisation whose id you provided. <br> If the organisation still has runners and/or teams associated this will fail. <br> To delete the organisation with all associated runners and teams set the force QueryParam to true (cascading deletion might take a while). <br> This won't delete the associated contact. <br> If no organisation with this id exists it will just return 204(no content).
     * @param id
     * @param force
     * @returns ResponseRunnerOrganisation
     * @returns ResponseEmpty
     * @throws ApiError
     */
    static runnerOrganisationControllerRemove(id: number, force?: boolean): Promise<ResponseRunnerOrganisation | ResponseEmpty>;
}
